@@ -37,9 +37,6 @@ impl Interpreter {
             __directory__: dir,
             __recursive__: recursive,
             __ast__: ast,
-
-            // variables needed for runtime
-            __files__: vec![],
             __file__: String::from(""),
         }
     }
