@@ -5,8 +5,8 @@ use sha1::{Digest, Sha1};
 use sha2::*;
 use std::fs;
 use std::fs::File;
-use std::io::prelude::*;
 use std::io;
+use std::io::prelude::*;
 use std::path::Path;
 pub use string::Str;
 pub use sum::Sum;
@@ -112,18 +112,10 @@ impl Sum for super::Interpreter {
     fn read_bytes_of_file(&self, path: &String) -> Vec<u8> {
         let mut buffer = Vec::new();
         let file = File::open(path);
-        match file {
-            Ok(f) => {
-                let mut reader = io::BufReader::new(f);
-                reader.read_to_end(&mut buffer).unwrap();
-            }
-            Err(e) => {
-                self.raise_error(
-                    "COULD NOT READ BYTES FROM FILE",
-                    format!("Cannot read {}: {:?}", self.__file__, e),
-                );
-            },
-        };
+        if let Ok(f) = file {
+            let mut reader = io::BufReader::new(f);
+            reader.read_to_end(&mut buffer).unwrap();
+        }
         buffer
     }
 }
