@@ -15,25 +15,18 @@ pub fn lex(source: &String) -> Vec<Token> {
 
     // convert logos' tokens to our own struct, that let us parse
     // the tokens easier and implement our own display formatting
-    loop {
-        let t_type = tokens.next();
-
-        // avoid an infinite loop, logos returns None when there
-        // are no tokens left
-        if t_type == None {
-            break;
-        }
-
+    while let Some(t_type) = tokens.next() {
         // prepare token values
-        let t_type = format!("{:?}", t_type.unwrap());
         let mut t_value = format!("{}", tokens.slice());
-        match t_type.as_str() {
-            "Var" => {
+
+        // remove unnecessary symbols on some Literals
+        match t_type {
+            Tokens::Var => {
                 let mut t_value_chars = t_value.chars();
                 t_value_chars.next();
                 t_value = t_value_chars.as_str().to_string();
             },
-            "Rgx" => {
+            Tokens::Rgx => {
                 let mut t_value_chars = t_value.chars();
                 t_value_chars.next();
                 t_value_chars.next_back();
@@ -43,7 +36,7 @@ pub fn lex(source: &String) -> Vec<Token> {
         }
 
         // create a struct with the token
-        let parsable_token = Token::new(t_type, t_value);
+        let parsable_token = Token::new(format!("{:?}", t_type), t_value);
 
         println_on_debug!("  {}", &parsable_token);
         parsable_tokens.push(parsable_token);
@@ -55,30 +48,14 @@ pub fn lex(source: &String) -> Vec<Token> {
 // Token list
 #[derive(Logos, Debug, PartialEq)]
 pub enum Tokens {
-    #[token("delete")]
-    #[token("create")]
-    #[token("mkdir")]
-    #[token("print")]
-    #[token("move")]
-    #[token("copy")]
-    #[token("rename")]
-    #[token("shell")]
-    #[token(" delete")]
-    #[token(" create")]
-    #[token(" mkdir")]
-    #[token(" print")]
-    #[token(" move")]
-    #[token(" copy")]
-    #[token(" rename")]
-    #[token(" shell")]
-    #[token("delete ")]
-    #[token("create ")]
-    #[token("mkdir ")]
-    #[token("print ")]
-    #[token("move ")]
-    #[token("copy ")]
-    #[token("rename ")]
-    #[token("shell ")]
+    #[regex(r#"( )*(delete)( )*"#)]
+    #[regex(r#"( )*(create)( )*"#)]
+    #[regex(r#"( )*(mkdir)( )*"#)]
+    #[regex(r#"( )*(print)( )*"#)]
+    #[regex(r#"( )*(move)( )*"#)]
+    #[regex(r#"( )*(copy)( )*"#)]
+    #[regex(r#"( )*(rename)( )*"#)]
+    #[regex(r#"( )*(shell)( )*"#)]
     Func,
     #[token("==")]
     Equal,
